@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.1';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.2';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -108,11 +108,22 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.3.1';
 #pod     [ReadmeAnyFromPod]
 #pod     [CPANFile]
 #pod
+#pod     [MetaNoIndex]
+#pod     directory = t
+#pod     directory = xt
+#pod     directory = inc
+#pod     directory = share
+#pod     directory = eg
+#pod     directory = examples
+#pod
+#pod     [MetaProvides::Package]
+#pod     [MetaConfig]
+#pod
 #pod     #
 #pod     # Auto generation --- tests
 #pod     #
 #pod     [Test::Inline]
-#pod     [ExtraTests]
+#pod     [RunExtraTests]
 #pod     [Test::Perl::Critic]
 #pod     [PodSyntaxTests]
 #pod     [Test::Pod::Coverage::Configurable]
@@ -295,7 +306,7 @@ sub configure {
             : ['Prereqs' => { 'Dist::Zilla::Plugin::Prereqs::FromCPANfile' => 0 }], # add manually because [MAXHQ::BundleDepsDeep] wont see it
         'AutoPrereqs',                    # collect prereqs from modules
         ['RemovePrereqs' => {
-            'remove' => [ qw( strict ) ],
+            'remove' => [ qw( strict warnings ) ],
         }],
 
         'CheckSelfDependency',            # Make sure no packages of this dist ended up in the prerequisites list
@@ -310,6 +321,17 @@ sub configure {
         'CPANFile',                       # add "cpanfile"
         'License',                        # add LICENSE
         'ReadmeAnyFromPod',               # add README (with dist's name, version, abstract, license)
+        ['MetaNoIndex' => {               # prevent CPAN from indexing these files (taken from https://metacpan.org/pod/Dist::Zilla::PluginBundle::Starter)
+            'directory' => [ qw( t xt inc share eg examples ) ],
+            $build_myself                 # don't index private modules of this bundle
+                ? ( 'package' => [ qw(
+                    Dist::Zilla::Plugin::ShareDir::ProjectDistDir
+                    Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep
+                ) ] )
+                : (),
+        }],
+        'MetaProvides::Package',          # specify provided packages in META.* instead of letting PAUSE figure them out
+        'MetaConfig',                     # add Dist::Zilla info to META.*
 
         #
         # Auto generation --- tests
@@ -317,7 +339,7 @@ sub configure {
         'Test::Inline',                   # generate .t files from inline test code (POD)
 
         # auto-generate various tests
-        'ExtraTests',
+        'RunExtraTests',
         'Test::Perl::Critic',
         'Test::Pod::Coverage::Configurable',
         'PodSyntaxTests',
@@ -370,7 +392,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.1';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.3.2';
 use Moose;
     use namespace::autoclean;
 
@@ -411,7 +433,7 @@ use Moose;
 {
     package Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep;
     # ABSTRACT: register all needed plugins in a bundle as runtime requirements
-$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.1';
+$Dist::Zilla::Plugin::MAXHQ::BundleDepsDeep::VERSION = '3.3.2';
 use Moose;
     use namespace::autoclean;
 
@@ -509,7 +531,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.3.1
+version 3.3.2
 
 =head1 SYNOPSIS
 
@@ -618,11 +640,22 @@ Currently this plugin bundle is equivalent to:
     [ReadmeAnyFromPod]
     [CPANFile]
 
+    [MetaNoIndex]
+    directory = t
+    directory = xt
+    directory = inc
+    directory = share
+    directory = eg
+    directory = examples
+
+    [MetaProvides::Package]
+    [MetaConfig]
+
     #
     # Auto generation --- tests
     #
     [Test::Inline]
-    [ExtraTests]
+    [RunExtraTests]
     [Test::Perl::Critic]
     [PodSyntaxTests]
     [Test::Pod::Coverage::Configurable]
